@@ -35,15 +35,11 @@ for fname in all_crc_fails:
     """
     First we check SABYenc
     """
-    output_buffer, output_filename, crc, crc_yenc, crc_correct = sabyenc3.decode_usenet_chunks(
-        data_chunks, data_size
-    )
+    output_buffer, output_filename, crc_correct = sabyenc3.decode_usenet_chunks(data_chunks, data_size)
     print("\n---- SABYenc output ----\n")
     print("Filename:", output_filename)
     print("Size:", len(output_buffer))
     print("NZB size:", data_size)
-    print("CRC Calc:", crc)
-    print("CRC Yenc:", crc_yenc)
     print("CRC Bool:", crc_correct)
 
     """
@@ -66,7 +62,7 @@ for fname in all_crc_fails:
     # Different from homemade
     flat_data = "".join(data)
     decoded_data, crc = _yenc.decode_string(flat_data)[:2]
-    partcrc = "%08X" % ((crc ^ -1) & 2 ** 32 - 1)
+    partcrc = "%08X" % ((crc ^ -1) & 2**32 - 1)
 
     if ypart:
         crcname = "pcrc32"
